==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebTabsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabComponentEventArgsDescriptionMetadata } from "./WebTabComponentEventArgsDescriptionMetadata";
import { WebTabsDescription } from "./WebTabsDescription";
/**
 * @hidden
 */
var WebTabsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabsDescriptionMetadata, _super);
    function WebTabsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabsDescriptionMetadata.b = function (a) {
        if (WebTabsDescriptionMetadata.a == null) {
            WebTabsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabsDescriptionMetadata.c(WebTabsDescriptionMetadata.a);
        }
        if (a.k(WebTabsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebTabsDescriptionMetadata.a);
        WebTabComponentEventArgsDescriptionMetadata.d(a);
    };
    WebTabsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tabs");
        a.item("__tagNameWC", "String:igc-tabs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Alignment", "ExportedType:string:TabsAlignment");
        a.item("Alignment@stringUnion", "WebComponents;React");
        a.item("Alignment@names", "Start;End;Center;Justify");
        a.item("Activation", "ExportedType:string:TabsActivation");
        a.item("Activation@stringUnion", "WebComponents;React");
        a.item("Activation@names", "Manual;Auto");
        a.item("ChangeRef", "EventRef::change");
    };
    WebTabsDescriptionMetadata.d = function (a) {
        WebTabsDescriptionMetadata.b(a);
        a.ad("WebTabs", function () { return new WebTabsDescription(); });
        a.ac("WebTabs", WebTabsDescriptionMetadata.a);
    };
    WebTabsDescriptionMetadata.$t = markType(WebTabsDescriptionMetadata, 'WebTabsDescriptionMetadata');
    WebTabsDescriptionMetadata.a = null;
    return WebTabsDescriptionMetadata;
}(Base));
export { WebTabsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebTabsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabComponentEventArgsDescriptionMetadata } from "./WebTabComponentEventArgsDescriptionMetadata";
import { WebTabsDescription } from "./WebTabsDescription";
/**
 * @hidden
 */
var WebTabsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabsDescriptionMetadata, _super);
    function WebTabsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabsDescriptionMetadata.b = function (a) {
        if (WebTabsDescriptionMetadata.a == null) {
            WebTabsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabsDescriptionMetadata.c(WebTabsDescriptionMetadata.a);
        }
        if (a.k(WebTabsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebTabsDescriptionMetadata.a);
        WebTabComponentEventArgsDescriptionMetadata.d(a);
    };
    WebTabsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tabs");
        a.item("__tagNameWC", "String:igc-tabs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Alignment", "ExportedType:string:TabsAlignment");
        a.item("Alignment@stringUnion", "WebComponents;React");
        a.item("Alignment@names", "Start;End;Center;Justify");
        a.item("Activation", "ExportedType:string:TabsActivation");
        a.item("Activation@stringUnion", "WebComponents;React");
        a.item("Activation@names", "Manual;Auto");
        a.item("ChangeRef", "EventRef::change");
    };
    WebTabsDescriptionMetadata.d = function (a) {
        WebTabsDescriptionMetadata.b(a);
        a.ae("WebTabs", function () { return new WebTabsDescription(); });
        a.ad("WebTabs", WebTabsDescriptionMetadata.a);
    };
    WebTabsDescriptionMetadata.$t = markType(WebTabsDescriptionMetadata, 'WebTabsDescriptionMetadata');
    WebTabsDescriptionMetadata.a = null;
    return WebTabsDescriptionMetadata;
}(Base));
export { WebTabsDescriptionMetadata };
